import base64
import sys
import os
import zipfile
from bs4 import BeautifulSoup

def convert(doc_text, file_out):
    """Decodes base64 content and writes it to a file."""
    with open(file_out, 'wb') as o:
        for line in doc_text.split('\r\n'):
            o.write(base64.b64decode(line))

def extract(file_in):
    """Extracts internal files from XML, saves and renames them."""
    with open(file_in, 'r', encoding='utf-8') as f:
        soup = BeautifulSoup(f, 'xml')
    
    counter = 0
    for internal_file in soup.find_all('internal-file'):
        zip_file_name = f"{file_in}_{counter}.zip"
        convert(internal_file.text, zip_file_name)
        
        # Extract the original file name from the 'file' element
        file_element = internal_file.find_parent('file')
        if file_element and file_element.has_attr('original'):
            original_path = file_element['original']
            # Use split to extract the file name after the last backslash
            original_name = original_path.split("\\")[-1]
        else:
            original_name = f"extracted_{counter}"  # Fallback name
        
        # Unzip the file and rename extracted content
        with zipfile.ZipFile(zip_file_name, 'r') as zip_ref:
            extracted_files = zip_ref.namelist()
            zip_ref.extractall()
        
        if extracted_files:
            extracted_file_path = extracted_files[0]  # Assume one file in ZIP
            new_file_path = os.path.join(os.getcwd(), original_name)
            os.rename(extracted_file_path, new_file_path)
            print(f"Extracted and renamed: {new_file_path}")
        
        counter += 1

# Process each file passed as argument
for arg in sys.argv[1:]:
    extract(arg)
